@@ -10,6 +10,7 @@ from .optimizer.generic_smbo import SMBO as Optimizer
 from .optimizer.parallel_smbo import pSMBO as ParallelOptimizer
 from .optimizer.message_queue_smbo import mqSMBO as DistributedOptimizer
 from .core.message_queue.worker import Worker as DistributedWorker
+from .optimizer.nsga_optimizer import NSGAOptimizer
 
 from .utils.start_smbo import create_smbo as create_optimizer
 
@@ -21,6 +22,7 @@ __all__ = [
     "__version__", "__package__", "package_name",
     "sp", "space",
     "Optimizer", "ParallelOptimizer", "DistributedOptimizer", "DistributedWorker",
+    "NSGAOptimizer",
     "create_optimizer",
     "get_config_space", "get_objective_function",
     "run_test",
