@@ -2,6 +2,10 @@ from ConfigSpace import Configuration, ConfigurationSpace
 from ConfigSpace import ConfigurationSpace, Configuration, Constant,\
      CategoricalHyperparameter, UniformFloatHyperparameter, \
      UniformIntegerHyperparameter, InCondition
-from ConfigSpace.read_and_write import pcs, pcs_new, json
 from openbox.utils.config_space.util import convert_configurations_to_array
 from ConfigSpace.util import get_one_exchange_neighbourhood
+
+import warnings
+with warnings.catch_warnings():
+     warnings.simplefilter("ignore", category=FutureWarning)
+     from ConfigSpace.read_and_write import pcs, pcs_new, json
